# py-XVis

Python implementation for XVis Toolbox release with the book Computer Vision for X-Ray Testing. Originally implemented 
in Matlab by Domingo Mery for the first edition of the book. This package is part of the second edition of the book 
Computer Vision for X-Ray Testing (November 2020).


# Requirements

- Python 3.6 or higher
- Numpy
- Scipy
- Matplotlib
- OpenCV 4.0 or higher


# Instalation
The package is part of the Python Index (PyPi). Installation is available by pip:

`pip install pyxivs`
